############################################################################################
# These scripts are licensed under the GNU General Public License (GPL).
# http://www.gnu.org/copyleft/gpl.html
# Find more info on the authors's website: http://aulix.com/articles/install-db2-on-debian
############################################################################################

Action=$1
#Version=$2
#set -x

if test -d /opt/IBM/db2/V8.1; then
	Version="8.1"
else
	if test -d /opt/ibm/db2/V9.7; then
		Version="9.7"
	fi
fi

#case $Action in
#( create_instance | drop_instance | upgrade_instance )
	case $Version in
	( 8.1 )
		DB2Path=/opt/IBM/db2/V8.1
	;;
	( 9.7 )
		DB2Path=/opt/ibm/db2/V9.7
	;;
	(*)
		echo Please specify the version of your db2 just after action arg: 8.1 or 9.7
		exit 0
	;;
	esac
#;;
#esac;

rebind_client()
{
	db2 bind /home/db2inst/sqllib/bnd/@db2ubind.lst blocking all grant public sqlerror continue;
	db2 bind /home/db2inst/sqllib/bnd/@db2cli.lst blocking all grant public;
}

config_dbm()
{ 
	ParamName=$1; Value=$2;
	db2 update dbm cfg using $ParamName $Value;
}

config_db()
{
	DBName=$1; ParamName=$2; Value=$3;
	db2 update db cfg for $DBName using $ParamName $Value;
}

restart_db2()
{
	db2stop force; db2start;
}

get_dbm_param()
{
	ParamName=$1;
	db2 get dbm config | grep "($ParamName)"| awk -F" = " '{print $2}';
}

enable_monitoring()
{
	config_dbm DFT_MON_BUFPOOL ON;
	config_dbm DFT_MON_LOCK ON;
	config_dbm DFT_MON_SORT ON;
}

case $Action in

( install_wse )
	cat /utils/db2/db2_rpm_list_wse.txt | /utils/exec_for_each_line.sh 'rpm -i' '.x86_64.rpm'
;;

( install_ese )
	cat /utils/db2/db2_rpm_list_ese.txt | /utils/exec_for_each_line.sh 'rpm -i' '.x86_64.rpm'
;;

( install_client )
	cat /utils/db2/db2_rpm_list_client.txt | /utils/exec_for_each_line.sh 'rpm -i' '.i386.rpm'
;;

( create_client )
	/utils/db2/do.sh delete_users
	groupadd -g 10999 db2iadm
	useradd -u 11004 -g db2iadm -m -d /home/db2inst db2inst
	usermod -aG db2iadm root
	#/opt/IBM/db2/V8.1/instance/db2istrt - purpose?
	$DB2Path/instance/db2icrt -a SERVER -s client db2inst
;;

( uninstall )
	cat /utils/db2/db2_rpm_list_all.txt | /utils/exec_for_each_line.sh 'rpm -e'
;;

( switch_to_wse )
	rpm -e IBM_db2conn81-8.1.3-156 IBM_db2pext81-8.1.3-156 IBM_db2essg81-8.1.3-156
	/utils/db2/do.sh install_wse
;;

( create_users )
	groupadd -g 10999 db2iadm
	groupadd -g 10998 db2fadm
	groupadd -g 10997 dasadm
	useradd -u 11004 -g db2iadm -m -d /home/db2inst db2inst
	useradd -u 11003 -g db2fadm -m -d /home/db2fenc db2fenc
	useradd -u 11002 -g dasadm -m -d /home/dasusr dasusr
	usermod -aG db2iadm,dasadm root
;;

( delete_users )
	userdel -r db2inst
	userdel -r db2fenc
	userdel -r dasusr
	groupdel db2iadm
	groupdel db2fadm
	groupdel  dasadm
;;

( recreate_users )
	/utils/db2/do.sh delete_users
	/utils/db2/do.sh create_users
;;

( create_instance )
#	set -x
	/utils/db2/do.sh recreate_users
#	License=$3
#	if test -n $License; then
#		License="-s "$License
#	fi
	$DB2Path/instance/dascrt -u dasusr
	$DB2Path/instance/db2icrt $2 $3 $4 $5 $6 $7 $8 -u db2fenc db2inst
#	-w 64
	$DB2Path/cfg/db2ln
	
#	echo -e "\nsource /home/db2inst/sqllib/db2profile" >> /root/.bashrc
	#echo -e "\nsource /home/dasusr/das/dasprofile" >> /root/.bashrc
	
	source /home/db2inst/sqllib/db2profile;
	db2set DB2COMM=tcpip
	db2 update dbm config using svcename 50000
	db2start
;;

( stop_das )
	su -c "source /home/dasusr/.profile; db2admin stop;" dasusr
;;

( stop_dog )
       	$DB2Path/bin/db2fmcu -d
        killall -s 9 db2fmcd db2fmd db2bp db2dasrrm
;;

( drop_instance )
#	set -x
	db2stop
	$DB2Path/instance/db2idrop db2inst
	/utils/db2/do.sh stop_das
	$DB2Path/instance/dasdrop
	/utils/db2/do.sh stop_dog
;;

( upgrade_db )
	DBName=$2
	db2updv8 -d $DBName
	db2rbind $DBName all -l /dev/stdout
	echo "NOTE!!!: If above failed increase statement cache: db2 update db config for $DBName using STMTHEAP 32000"
	db2 terminate; db2 connect to $DBName;
	db2 bind /home/db2inst/sqllib/bnd/db2schema.bnd blocking all grant public sqlerror continue;
	db2 bind /home/db2inst/sqllib/bnd/db2dsproc.bnd blocking all grant public;
	rebind_client;
	echo "NOTE!!!: Do following on each client with different db2level: /utils/db2/do.sh rebind_client"
	echo -e "\n SQL procedures and all external libraries must be rebuilt on the new platform"
	db2 terminate;
;;

( rebind_client )
	rebind_client;
;;

( upgrade_instance )
	db2stop force;
	$DB2Path/instance/dasupdt;
	$DB2Path/instance/db2iupdt db2inst;
	db2start;
;;

( config_kernel )
	echo "# ***** DB2 config: *****" >> /etc/sysctl.conf;
	echo "kernel.sem=250 256000 32 1024" >> /etc/sysctl.conf;
	echo "kernel.msgmax=65535" >> /etc/sysctl.conf;
	echo "kernel.msgmnb=65535" >> /etc/sysctl.conf;
	SystemMem=`cat /proc/meminfo | grep MemTotal:|awk '{print $2}'`;
	echo "kernel.shmall=$[SystemMem/4*9/10]" >> /etc/sysctl.conf;
	echo "kernel.shmmax=1073741824" >> /etc/sysctl.conf;
	sysctl -p;
	ipcs -l;
;;

( config_db1 )
	db2set DB2_PARALLEL_IO=4;
	db2set DB2_EVALUNCOMMITTED=ON;
	db2set DB2_SKIPINSERTED=ON;
	db2set DB2_SKIPDELETED=ON;

	DBName=$2	
	config_db $DBName LOCKLIST 100000;
	SORTHEAP=20000;	config_db $DBName SORTHEAP $SORTHEAP; config_dbm SHEAPTHRES $[4*$SORTHEAP];
	config_db $DBName SHEAPTHRES_SHR 1000;
	config_db $DBName MAXLOCKS 20;
	config_db $DBName LOGRETAIN NO;
	config_db $DBName AUTO_REORG OFF;
	MAXAGENTS=`get_dbm_param MAXAGENTS`; config_dbm MAXCAGENTS $[MAXAGENTS/2];
	# config_db $DBName LOGBUFSZ 128; was
	enable_monitoring;
	restart_db2;
;;

( config_dbm | config_db | restart_db2 )
	$Action $2 $3 $4
;;

(*)
	echo Please specify an action like: install_rpms_64, remove_rpms, create_users, delete_users, create_instance, drop_instance
	echo Sample: do.sh create_instance 9.7
	exit 0
;;
esac;